<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Profilegrid_elementor_content_restrictions
 * @subpackage Profilegrid_elementor_content_restrictions/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Profilegrid_elementor_content_restrictions
 * @subpackage Profilegrid_elementor_content_restrictions/admin
 * @author     Your Name <email@example.com>
 */
use \Elementor\Plugin as Elementor_Plugin;
use \Elementor\Controls_Manager;
use \Elementor\Core\Documents_Manager;

class Profilegrid_elementor_content_restrictions_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $Profilegrid_elementor_content_restrictions    The ID of this plugin.
	 */
	private $Profilegrid_elementor_content_restrictions;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $Profilegrid_elementor_content_restrictions       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $Profilegrid_elementor_content_restrictions, $version,$minimum_elementor_version,$minimum_php_version ) {

		$this->Profilegrid_elementor_content_restrictions = $Profilegrid_elementor_content_restrictions;
		$this->version = $version;
                $this->minimum_elementor_version = $minimum_elementor_version;
                $this->minimum_php_version = $minimum_php_version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_elementor_content_restrictions_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_elementor_content_restrictions_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
            if (class_exists('Profile_Magic') ) {
                wp_enqueue_style( $this->Profilegrid_elementor_content_restrictions, plugin_dir_url( __FILE__ ) . 'css/profilegrid-elementor-content-restrictions-admin.css', array(), $this->version, 'all' );
                
                
            }
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
            
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_elementor_content_restrictions_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_elementor_content_restrictions_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
            if (class_exists('Profile_Magic') ) {
                $dbhandler = new PM_DBhandler;
                wp_enqueue_script( $this->Profilegrid_elementor_content_restrictions, plugin_dir_url( __FILE__ ) . 'js/profilegrid-elementor-content-restrictions-admin.js', array( 'jquery','wp-color-picker' ), $this->version, true );
              
                
            }
	}
        
        public function admin_notice_missing_main_plugin() 
        {
            if ( ! did_action( 'elementor/loaded' ) ) 
            {
            $plugin = trim(basename(plugin_dir_path(dirname( __FILE__))).'/profilegrid-elementor-content-restrictions.php');
            deactivate_plugins($plugin);
            ?>
            <div class="notice notice-success is-dismissible">
                <p><?php echo sprintf(__( "Profilegrid Elementor content restriction work with Elementor Plugin, you need to activate the Elementor plugin .", 'profilegrid-elementor-content-restrictions') ); ?></p>
            </div>
            <?php
            }
           
	}
        
	public function profile_magic_elementor_content_restriction_notice_fun()
        {
            if (!class_exists('Profile_Magic') ) 
	    {
               $this->elementor_content_restriction_installation();
                    //wp_die( "ProfileGrid Stripe won't work as unable to locate ProfileGrid plugin files." );
            }
        }
        
        public function elementor_content_restriction_installation()
        {
            $plugin_slug= 'profilegrid-user-profiles-groups-and-communities';
            $installUrl = admin_url('update.php?action=install-plugin&plugin=' . $plugin_slug);
            $installUrl = wp_nonce_url($installUrl, 'install-plugin_' . $plugin_slug);
            ?>
            <div class="notice notice-success is-dismissible">
                <p><?php echo sprintf(__( "ProfileGrid Elementor Content Restriction work with ProfileGrid Plugin. You can install it  from <a href='%s'>Here</a>.", 'profilegrid-user-display-name' ),$installUrl); ?></p>
            </div>
            <?php
            $plugin = trim(basename(plugin_dir_path(dirname(__FILE__))) . '/profilegrid-elementor-content-restrictions.php');
        deactivate_plugins($plugin);
        }
	
        public function admin_notice_minimum_elementor_version() 
        {
		$plugin = trim(basename(plugin_dir_path(dirname( __FILE__))).'/profilegrid-elementor-content-restrictions.php');
                deactivate_plugins($plugin);
		
	}
        
        public function admin_notice_minimum_php_version() {
		deactivate_plugins( plugin_basename( ELEMENTOR_AWESOMESAUCE ) );

		return sprintf(
			wp_kses(
				'<div class="notice notice-warning is-dismissible"><p><strong>"%1$s"</strong> requires <strong>"%2$s"</strong> version %3$s or greater.</p></div>',
				array(
					'div' => array(
						'class'  => array(),
						'p'      => array(),
						'strong' => array(),
					),
				)
			),
			'ProfileGrid Elementor Content Restrictions',
			'Elementor',
			$this->minimum_php_version
		);
	}
        
        public function register_widgets()
        {
            
             require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widget/class-pg-elementor-widget.php'; 
              \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Elementor_PG_Widget() );
  
        }
        
        public function register_controls() 
        {
            require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/time.php';
            $time_input = new Control_Time;
            Elementor_Plugin::instance()->controls_manager->register_control( 'time', new Control_Time );
	}
        
        public function register_control_section( $element ) {
		

		$element->start_controls_section(
			'profilegrid_elementor_control_section',
			[
				'tab' => Controls_Manager::TAB_ADVANCED,
				'label' => __( 'ProfileGrid Restrict Content', 'profilegrid-elementor-content-restrictions' ),
			]
		);
		$element->end_controls_section();
	}

	public function control_actions( $element, $args ) {
            $helper = new ProfileGrid_Elementor_Helper;
            
		$element->add_control(
			'enable_restriction',
			[
				'label'        => __( 'Enable Restriction', 'profilegrid-elementor-content-restrictions' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => '',
				'label_on'     => __( 'Yes', 'profilegrid-elementor-content-restrictions' ),
				'label_off'    => __( 'No', 'profilegrid-elementor-content-restrictions' ),
				'return_value' => 'yes',
			]
		);

		$element->add_control(
			'show_content_to',
			[
				'type'			=> Controls_Manager::SELECT2,
				'label'			=> __( 'Show Content to', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'Visibility rules. Multiple rules can be set.', 'profilegrid-elementor-content-restrictions' ),
				'options' 		=> $helper->profilegrid_elementor_show_content_to(),
				'multiple' 		=> true,
				'label_block' 	=> true,
				'condition'   	=> [
					'enable_restriction'  => 'yes'
				],
			]
		);

		$element->add_control(
			'show_content_to_roles',
			[
				'type'			=> Controls_Manager::SELECT2,
				'label'			=> __( 'Select User Role', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'Select roles you want to show the content to', 'profilegrid-elementor-content-restrictions' ),
				'options' 		=> $helper->profilegrid_elementor_show_content_to_roles(),
				'separator' 	=> 'before',
				'multiple' 		=> true,
				'label_block' 	=> true,
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'role-wise'
				],
			]
		);
                
                $element->add_control(
			'show_content_to_groups',
			[
				'type'			=> Controls_Manager::SELECT2,
				'label'			=> __( 'Select Group(s)', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'Select groups you want to show the content to', 'profilegrid-elementor-content-restrictions' ),
				'options' 		=> $helper->profilegrid_elementor_show_content_to_groups(),
				'separator' 	=> 'before',
				'multiple' 		=> true,
				'label_block' 	=> true,
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'group-wise'
				],
			]
		);



		$element->add_control(
			'user_ids',
			[
				'type'			=> Controls_Manager::TEXT,
				'label'			=> __( 'User ID\'s', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'Input user IDs you want to show the content to. Separate each ID with comma delimeter.', 'profilegrid-elementor-content-restrictions' ),
				'separator' 	=> 'before',
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'user-wise'
				],
			]
		);

		$element->add_control(
			'date_time_type',
			[
				'type'			=> Controls_Manager::SELECT,
				'label'			=> __( 'Select Time Type', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'Show an alternative of your main content', 'profilegrid-elementor-content-restrictions' ),
				'options' => [
					'daily' => __( 'Everyday', 'profilegrid-elementor-content-restrictions' ),
					'date'	=> __( 'Specific Date', 'profilegrid-elementor-content-restrictions' ),
					'day' 	=> __( 'Specific Day', 'profilegrid-elementor-content-restrictions' ),
				],
				'separator' 	=> 'before',				
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'date-time'
				],
			]
		);

		$element->add_control(
			'profilegrid_elementor_day_list',
			[
				'type'			=> Controls_Manager::SELECT2,
				'label'			=> __( 'Select Days', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'Select the days you want to show the content on', 'profilegrid-elementor-content-restrictions' ),
				'options' 		=> [
					'sat' => __( 'Saturday', 'profilegrid-elementor-content-restrictions' ),
					'sun' => __( 'Sunday', 'profilegrid-elementor-content-restrictions' ),
					'mon' => __( 'Monday', 'profilegrid-elementor-content-restrictions' ),
					'tue' => __( 'Tuesday', 'profilegrid-elementor-content-restrictions' ),
					'wed' => __( 'Wednesday', 'profilegrid-elementor-content-restrictions' ),
					'thu' => __( 'Thursday', 'profilegrid-elementor-content-restrictions' ),
					'fri' => __( 'Friday', 'profilegrid-elementor-content-restrictions' )
				],
				'multiple' 		=> true,
				'label_block' 	=> true,				
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'date-time',
					'date_time_type'  		=> 'day'
				],
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'profilegrid_elementor_dates', [
				'label' => __( '', 'profilegrid-elementor-content-restrictions' ),				
				'type' => Controls_Manager::DATE_TIME,
				'picker_options' => [ 'enableTime' => false ],
				'default' => date( 'Y-m-d', strtotime( 'yesterday' ) ),
				'label_block' => true,
			]
		);

		$element->add_control(
			'profilegrid_elementor_date_list',
			[
				'label' => __( 'Choose Dates', 'profilegrid-elementor-content-restrictions' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'profilegrid_elementor_dates' => date( 'Y-m-d', strtotime( 'yesterday' ) ),
					],
				],				
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'date-time',
					'date_time_type'  		=> 'date'
				],
				'title_field' => '{{{ profilegrid_elementor_dates }}}',
			]
		);

		$element->add_control(
			'rewdt_specific_time',
			[
				'label'        => __( 'Show at specific times?', 'profilegrid-elementor-content-restrictions' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => '',
				'label_on'     => __( 'Yes', 'profilegrid-elementor-content-restrictions' ),
				'label_off'    => __( 'No', 'profilegrid-elementor-content-restrictions' ),
				'return_value' => 'yes',			
				'separator' 	=> 'before',			
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'date-time',
				],
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'profilegrid_elementor_time_title',
			[
				'label' => __( 'Name', 'profilegrid-elementor-content-restrictions' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Time #1', 'profilegrid-elementor-content-restrictions' )
			]
		);

		$repeater->add_control(
			'profilegrid_elementor_due_time_from',
			[
				'label' => __( 'Time From', 'profilegrid-elementor-content-restrictions' ),
				'type' => 'time',				
			]
		);

		$repeater->add_control(
			'profilegrid_elementor_due_time_to',
			[
				'label' => __( 'Time To', 'profilegrid-elementor-content-restrictions' ),
				'type' => 'time',
			]
		);

		$element->add_control(
			'profilegrid_elementor_time_list',
			[
				'label' => __( 'Choose Times', 'profilegrid-elementor-content-restrictions' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'profilegrid_elementor_time_title' => __( 'Monring', 'profilegrid-elementor-content-restrictions' ),
						'profilegrid_elementor_due_time_from' => '06:00',
						'profilegrid_elementor_due_time_to' => '11:00'
					],
					[
						'profilegrid_elementor_time_title' => __( 'Time #2', 'profilegrid-elementor-content-restrictions' ),
						'profilegrid_elementor_due_time_from' => '18:00',
						'profilegrid_elementor_due_time_to' => '22:00'
					],
				],				
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'date-time',
					'rewdt_specific_time'  	=> 'yes'
				],
				'title_field' => '{{{ profilegrid_elementor_time_title }}}',
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'profilegrid_elementor_query_key',
			[
				'label' => __( 'Key', 'profilegrid-elementor-content-restrictions' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'key', 'profilegrid-elementor-content-restrictions' )
			]
		);

		$repeater->add_control(
			'profilegrid_elementor_query_value',
			[
				'label' => __( 'Value', 'profilegrid-elementor-content-restrictions' ),
				'type' => Controls_Manager::TEXT,				
				'default' => __( 'value', 'profilegrid-elementor-content-restrictions' )			
			]
		);

		$element->add_control(
			'profilegrid_elementor_query_relation',
			[
				'type'			=> Controls_Manager::SELECT,
				'label'			=> __( 'Query Relation', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'If AND is selected, all condition pairs need to match. If OR is selected, matching any of them would show it.', 'profilegrid-elementor-content-restrictions' ),
				'options' => [
					'AND' 	=> __( 'AND', 'profilegrid-elementor-content-restrictions' ),
					'OR'	=> __( 'OR', 'profilegrid-elementor-content-restrictions' )
				],
				'separator' 	=> 'before',				
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'query-string'
				],
			]
		);

		$element->add_control(
			'profilegrid_elementor_query_list',
			[
				'label' => __( 'Queries', 'profilegrid-elementor-content-restrictions' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'profilegrid_elementor_query_key'		=> __( 'key1', 'profilegrid-elementor-content-restrictions' ),
						'profilegrid_elementor_query_value'	=> 'value1'
					],
					[
						'profilegrid_elementor_query_key'		=> __( 'key2', 'profilegrid-elementor-content-restrictions' ),
						'profilegrid_elementor_query_value'	=> 'value2'
					],
				],				
				'condition'   	=> [
					'enable_restriction'  	=> 'yes',
					'show_content_to'  		=> 'query-string'
				],
				'title_field' => '{{{ profilegrid_elementor_query_key }}}',
			]
		);

		do_action( 'profilegrid_elementor_before_message_control', $element );

		$element->add_control(
			'show_message',
			[
				'type'			=> Controls_Manager::SELECT,
				'label'			=> __( 'Show Alternate Content', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'Show an alternative of your main content', 'profilegrid-elementor-content-restrictions' ),
				'options' => [
					'nomessage' => __( 'Nothing', 'profilegrid-elementor-content-restrictions' ),
					'text' 		=> __( 'Plain Text', 'profilegrid-elementor-content-restrictions' ),
					'template' 	=> __( 'Template', 'profilegrid-elementor-content-restrictions' )
				],
				'default'		=> 'plaintext',
				'separator' 	=> 'before',
				'condition'   	=> [
					'enable_restriction'  => 'yes'
				],
			]
		);

		$element->add_control(
			'message_text',
			[
				'type'			=> Controls_Manager::WYSIWYG,
				'label'			=> __( 'Your Message', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'This message will be shown as an alternate of your content', 'profilegrid-elementor-content-restrictions' ),
				'default'      	=> __( 'This content is restricted!', 'profilegrid-elementor-content-restrictions' ),
				'condition'   => [
					'enable_restriction'  	=> 'yes',
					'show_message'  		=> 'text'
				],
			]
		);

		$element->add_control(
			'message_template',
			[
				'type'			=> Controls_Manager::SELECT,
				'label'			=> __( 'Choose a <strong>Section</strong> template', 'profilegrid-elementor-content-restrictions' ),
				'description'	=> __( 'This template will be shown as an alternate of your main content', 'profilegrid-elementor-content-restrictions' ),
				'options' 		=> $helper->profilegrid_elementor_get_message_templates(),
				'label_block' 	=> true,
				'condition'   => [
					'enable_restriction'  	=> 'yes',
					'show_message'  		=> 'template'
				],
			]
		);
	}


        
}
