<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Profilegrid_elementor_content_restrictions
 * @subpackage Profilegrid_elementor_content_restrictions/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Profilegrid_elementor_content_restrictions
 * @subpackage Profilegrid_elementor_content_restrictions/includes
 * @author     Your Name <email@example.com>
 */
class Profilegrid_elementor_content_restrictions {

        
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Profilegrid_elementor_content_restrictions_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $Profilegrid_elementor_content_restrictions    The string used to uniquely identify this plugin.
	 */
	protected $Profilegrid_elementor_content_restrictions;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;
      
	protected $minimum_elementor_version;
	protected $minimum_php_version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
          
	


		$this->Profilegrid_elementor_content_restrictions = 'profilegrid-elementor-content-restrictions';
		$this->version = '1.0.0';
                $this->minimum_elementor_version = '2.0.0';
                $this->minimum_php_version = '7.0';
		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
                ob_start();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Profilegrid_elementor_content_restrictions_Loader. Orchestrates the hooks of the plugin.
	 * - Profilegrid_elementor_content_restrictions_i18n. Defines internationalization functionality.
	 * - Profilegrid_elementor_content_restrictions_Admin. Defines all hooks for the admin area.
	 * - Profilegrid_elementor_content_restrictions_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-profilegrid-elementor-content-restrictions-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-profilegrid-elementor-content-restrictions-i18n.php';
                require_once plugin_dir_path(  dirname( __FILE__ )) . 'includes/class-profilegrid-elementor-content-restrictions-activator.php';
                require_once plugin_dir_path( dirname( __FILE__ )   ) . 'includes/class-profilegrid-elementor-content-restrictions-deactivator.php';
                
		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-profilegrid-elementor-content-restrictions-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-profilegrid-elementor-content-restrictions-public.php'; 
               
                $this->loader = new Profilegrid_elementor_content_restrictions_Loader();

                require_once plugin_dir_path(dirname(__FILE__)).'includes/class-profilegrid-elementor-content-restrictions-helper.php';
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Profilegrid_elementor_content_restrictions_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {
		$plugin_i18n = new Profilegrid_elementor_content_restrictions_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private

	 */
	private function define_admin_hooks() {

		$plugin_admin = new Profilegrid_elementor_content_restrictions_Admin( $this->get_Profilegrid_elementor_content_restrictions(), $this->get_version(),$this->minimum_elementor_version,$this->minimum_php_version );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
                $this->loader->add_action( 'admin_notices', $plugin_admin, 'profile_magic_elementor_content_restriction_notice_fun' );
                $this->loader->add_action( 'network_admin_notices', $plugin_admin, 'profile_magic_elementor_content_restriction_notice_fun' );
		
                // Check if Elementor installed and activated.
		if ( ! did_action( 'elementor/loaded' ) ) {
			$this->loader->add_action( 'admin_notices', $plugin_admin, 'admin_notice_missing_main_plugin' );
			return;
		}

		// Check for required Elementor version.
		if ( ! version_compare( ELEMENTOR_VERSION,$this->minimum_elementor_version, '>=' ) ) {
			$this->loader->add_action( 'admin_notices', $plugin_admin, 'admin_notice_minimum_elementor_version');
			return;
		}

		// Check for required PHP version.
		if ( version_compare( PHP_VERSION,$this->minimum_php_version, '<' ) ) {
			$this->loader->add_action( 'admin_notices',$plugin_admin, 'admin_notice_minimum_php_version');
			return;
		}
                // Register widgets
               // $this->loader->add_action( 'elementor/widgets/widgets_registered',$plugin_admin, 'register_widgets');

                
                $this->loader->add_action( 'elementor/controls/controls_registered',$plugin_admin, 'register_controls' );
                $this->loader->add_action( 'elementor/element/common/_section_style/before_section_start',$plugin_admin, 'register_control_section' );
                $this->loader->add_action( 'elementor/element/column/layout/after_section_end',$plugin_admin, 'register_control_section' );
                $this->loader->add_action( 'elementor/element/section/section_typo/after_section_end',$plugin_admin, 'register_control_section' );
                $this->loader->add_action( 'elementor/element/common/profilegrid_elementor_control_section/before_section_end', $plugin_admin,'control_actions', 10, 2 );
                $this->loader->add_action( 'elementor/element/column/profilegrid_elementor_control_section/before_section_end', $plugin_admin,'control_actions', 10, 2 );
                $this->loader->add_action( 'elementor/element/section/profilegrid_elementor_control_section/before_section_end', $plugin_admin,'control_actions', 10, 2 );

		// Once we get here, We have passed all validation checks so we can safely include our widgets.
		//require_once 'class-widgets.php';
               
                
                
        }

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {
            $plugin_public = new Profilegrid_elementor_content_restrictions_Public( $this->get_Profilegrid_elementor_content_restrictions(), $this->get_version() );
            $this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles',999999999999 );
            $this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts',999999999999 );
            $this->loader->add_filter( 'elementor/frontend/section/should_render',$plugin_public, 'restrict_render_section', 10, 2 );
            $this->loader->add_filter( 'elementor/frontend/column/should_render', $plugin_public,'restrict_render_section', 10, 2 );
            $this->loader->add_filter( 'elementor/widget/render_content',$plugin_public, 'restrict_render_widgets', 10, 2 );

            //$this->loader->add_filter('the_content',$plugin_public, 'pg_check_content_access',999999999999);
   }

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_Profilegrid_elementor_content_restrictions() {
		return $this->Profilegrid_elementor_content_restrictions;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Profilegrid_elementor_content_restrictions_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

        
	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
