<?php
/**
 * Elementor oEmbed Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Elementor_PG_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve oEmbed widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'profilegridelementor';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve oEmbed widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Profilegrid Elementor', 'plugin-name' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve oEmbed widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-lock';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the oEmbed widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'general' ];
	}

	/**
	 * Register Profilegrid Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
            
                

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Profilegrid Restrictions', 'plugin-name' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'access_permissions',
			[
				'label' => __( 'Access Permissions', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
                                'class' => 'pg_elementor_class',
				'options' => [
					'pg_restriction_1' => [
						'title' => __( 'Content accessible to Everyone', 'plugin-name' ),
						'icon' => 'fa fa-lock',
					],
					'pg_restriction_2' => [
						'title' => __( 'Content accessible to Logged In Users', 'plugin-name' ),
						'icon' => 'fa fa-lock',
					],
					'pg_restriction_3' => [
						'title' => __( 'Members of Author\'s Groups', 'plugin-name' ),
						'icon' => 'fa fa-lock',   
					]
                                        ,
                                        'pg_restriction_4' => [
                                                    'title' => __( 'Content accessible to My Friends', 'plugin-name' ),
                                                    'icon' => 'fa fa-lock',
                                            ],
                                        'pg_restriction_5' => [
                                                    'title' => __( 'Content accessible to Only Me', 'plugin-name' ),
                                                    'icon' => 'fa fa-lock',
                                            ],
				],
				'default' => 'pg_restriction_1',
			]
		);
                

                $dbhandler = new PM_DBhandler;
                $groups = $dbhandler->get_all_result('GROUPS');
                
                foreach($groups as $group) 
                {
                    $ids      =   $group->id;
                    $options[$ids]  =   $group->group_name;
                }
               
                $this->add_control(
			'pg_elementor_groups_list',
			[
				'label' => __( 'Select the User Group', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => $options,
                           'condition'    => ['access_permissions' => 'pg_restriction_2'],
			]
		);
               
                   
               //print_r($_POST['elementor-choose-access_permissions-c543']).'rrrrrrrrrrr';
                //$settings = $this->get_settings_for_display();
               

              
//                $this->add_control(
//			'url',
//			[
//				'label' => __( 'URL to embed', 'plugin-name' ),
//				'type' => \Elementor\Controls_Manager::TEXT,
//				'input_type' => 'url',
//				'placeholder' => __( 'https://your-link.com', 'plugin-name' ),
//                            
//			]
//                        
//		);
                
               
		$this->end_controls_section();

	}

	/**
	 * Render oEmbed widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();

		//$html = wp_oembed_get( $settings['url'] );

		echo '<div class="pg-content-elementor-widget">';

		//echo ( $html ) ? $html : $settings['url'];
                //print_r($settings['pg_elementor_groups_list']);
                $post_id = get_the_ID();
                switch($settings['access_permissions'])
                {
                    case 'pg_restriction_1':
                        
                        if(isset($settings['access_permissions']))
			{
				update_post_meta($post_id,'pm_content_access',$settings['access_permissions']);
			}
                        
                        break;
                    case 'pg_restriction_2':
                        
                        if(isset($settings['access_permissions']))
			{
				update_post_meta($post_id,'pm_content_access',$settings['access_permissions']);
                                if($settings['pg_elementor_groups_list'] != '')
                                {
                                    update_post_meta($post_id,'pm_elementor_selected_groups',$settings['pg_elementor_groups_list']);
                                }
                                else
                                {
                                    update_post_meta($post_id,'pm_elementor_selected_groups','all');
                                }
                                
			}
                        
                        break;
                    case 'pg_restriction_3':
                        
                        if(isset($settings['access_permissions']))
			{
				update_post_meta($post_id,'pm_content_access',$settings['access_permissions']);
			}
                        
                        break;
                    case 'pg_restriction_4':
                        
                        if(isset($settings['access_permissions']))
			{
				update_post_meta($post_id,'pm_content_access',$settings['access_permissions']);
			}
                        
                        break;
                    case 'pg_restriction_5':
                        
                        if(isset($settings['access_permissions']))
			{
				update_post_meta($post_id,'pm_content_access',$settings['access_permissions']);
			}
                        
                        break;
                        
                    
                }

		echo '</div>';

	}

}