<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://profilegrid.co
 * @since      1.0.0
 *
 * @package    Profilegrid_elementor_groups_widget
 * @subpackage Profilegrid_elementor_groups_widget/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Profilegrid_elementor_groups_widget
 * @subpackage Profilegrid_elementor_groups_widget/admin
 * @author     profilegrid
 */

class Profilegrid_elementor_groups_widget_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $Profilegrid_elementor_groups_widget   The ID of this plugin.
	 */
	private $Profilegrid_elementor_groups_widget;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $Profilegrid_elementor_groups_widget       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $Profilegrid_elementor_groups_widget, $version,$minimum_elementor_version,$minimum_php_version ) {

		$this->Profilegrid_elementor_groups_widget = $Profilegrid_elementor_groups_widget;
		$this->version = $version;
                $this->minimum_elementor_version = $minimum_elementor_version;
                $this->minimum_php_version = $minimum_php_version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_elementor_groups_widget_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_elementor_groups_widget_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
            if (class_exists('Profile_Magic') ) {
                wp_enqueue_style( $this->Profilegrid_elementor_groups_widget, plugin_dir_url( __FILE__ ) . 'css/profilegrid-elementor-groups-widget-admin.css', array(), $this->version, 'all' );
                
                
            }
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
            
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_elementor_groups_widget_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_elementor_content_restrictions_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
            if (class_exists('Profile_Magic') ) {
                $dbhandler = new PM_DBhandler;
                wp_enqueue_script( $this->Profilegrid_elementor_groups_widget, plugin_dir_url( __FILE__ ) . 'js/profilegrid-elementor-groups-widget-admin.js', array( 'jquery','wp-color-picker' ), $this->version, true );
              
                
            }
	}
    public function profilegrid_groups_widget_admin_menu(){
        add_submenu_page("",__("Elementor Groups Widget Settings","profilegrid-elementor-groups-widget"),__("Elementor Groups Widget Settings","profilegrid-elementor-groups-widget"),"manage_options","pm_elementor_groups_widget_settings",array( $this, 'pm_elementor_groups_widget_settings' ));
    }
    public function pm_elementor_groups_widget_settings(){
        include 'partials/profilegrid-elementor-groups-widget-admin-display.php';
    }
     public function profilegrid_elementor_widget_add_option_setting_page(){
     	include 'partials/profilegrid-elementor-groups-widget-setting-option.php';
     }    
    
    public function admin_notice_missing_main_plugin() {
            if ( ! did_action( 'elementor/loaded' ) ) 
            {
            $plugin = trim(basename(plugin_dir_path(dirname( __FILE__))).'/profilegrid-elementor-groups-widget.php');
            deactivate_plugins($plugin);
            ?>
            <div class="notice notice-success is-dismissible">
                <p><?php echo sprintf(__( "Profilegrid Elementor groups widget work with Elementor Plugin, you need to activate the Elementor plugin .", 'profilegrid-elementor-groups-widget') ); ?></p>
            </div>
            <?php
            }
           
	}
        
	public function profile_magic_elementor_groups_widget_fun(){
        if (!class_exists('Profile_Magic') ){
            $this->elementor_groups_widget_installation();
        }
    }
        
    public function elementor_groups_widget_installation(){
        $plugin_slug= 'profilegrid-user-profiles-groups-and-communities';
        $installUrl = admin_url('update.php?action=install-plugin&plugin=' . $plugin_slug);
        $installUrl = wp_nonce_url($installUrl, 'install-plugin_' . $plugin_slug);?>
        <div class="notice notice-success is-dismissible">
            <p><?php echo sprintf(__( "ProfileGrid Elementor Groups Widget work with ProfileGrid Plugin. You can install it  from <a href='%s'>Here</a>.", 'profilegrid-elementor-groups-widget'),$installUrl); ?></p>
        </div>
            <?php
        $plugin = trim(basename(plugin_dir_path(dirname(__FILE__))) . '/profilegrid-elementor-groups-widget.php');
        deactivate_plugins($plugin);
    }
	
    public function admin_notice_minimum_elementor_version(){
		$plugin = trim(basename(plugin_dir_path(dirname( __FILE__))).'/profilegrid-elementor-groups-widget.php');
                deactivate_plugins($plugin);
	}
        
    public function admin_notice_minimum_php_version() {
		deactivate_plugins( plugin_basename( ELEMENTOR_AWESOMESAUCE ) );
		return sprintf(
			wp_kses(
				'<div class="notice notice-warning is-dismissible"><p><strong>"%1$s"</strong> requires <strong>"%2$s"</strong> version %3$s or greater.</p></div>',
				array(
					'div' => array(
						'class'  => array(),
						'p'      => array(),
						'strong' => array(),
					),
				)
			),
			'ProfileGrid Elementor Groups Widget',
			'Elementor',
			$this->minimum_php_version
		);
	}

	public function register_widgets(){
		$dbhandler = new PM_DBhandler;
		$groups_widget_option = $dbhandler->get_global_option_value('pm_enable_elementor_groups_widget');
		$users_widget_option = $dbhandler->get_global_option_value('pm_enable_elementor_users_widget');
		if($groups_widget_option){
	        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widget/class-pg-elementor-widget.php'; 
	        \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Elementor_PG_Groups_Widget() );
  		}

  		if($users_widget_option){
	        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widget/class-pg-elementor-widget-users.php'; 
	        \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Elementor_PG_Widget_Users() );
  		}
    }
        
    public function add_elementor_widget_categories( $elements_manager ){
    	$elements_manager->add_category(
			'profile-grid',
			[
				'title' => __( 'Profile Grid', 'profilegrid-elementor-groups-widget' ),
				'icon' => 'fa fa-plug',
			]
		);
    }
        

        
}
