<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://profilegrid.co
 * @since      1.0.0
 *
 * @package    Profilegrid_elementor_groups_widget
 * @subpackage Profilegrid_elementor_groups_widget/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Profilegrid_elementor_groups_widget
 * @subpackage Profilegrid_elementor_groups_widget/includes
 * @author     profilegrid
 */
class Profilegrid_elementor_groups_widget {

        
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Profilegrid_elementor_groups_widget_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $Profilegrid_elementor_groups_widget    The string used to uniquely identify this plugin.
	 */
	protected $Profilegrid_elementor_groups_widget;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;
      
	protected $minimum_elementor_version;
	protected $minimum_php_version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
          
	


		$this->Profilegrid_elementor_groups_widget = 'profilegrid-elementor-groups-widget';
		$this->version = '1.0.0';
                $this->minimum_elementor_version = '2.0.0';
                $this->minimum_php_version = '7.0';
		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
                ob_start();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Profilegrid_elementor_groups_widget_Loader. Orchestrates the hooks of the plugin.
	 * - Profilegrid_elementor_groups_widget_i18n. Defines internationalization functionality.
	 * - Profilegrid_elementor_groups_widget_Admin. Defines all hooks for the admin area.
	 * - Profilegrid_elementor_groups_widget_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-profilegrid-elementor-groups-widget-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-profilegrid-elementor-groups-widget-i18n.php';
                require_once plugin_dir_path(  dirname( __FILE__ )) . 'includes/class-profilegrid-elementor-groups-widget-activator.php';
                require_once plugin_dir_path( dirname( __FILE__ )   ) . 'includes/class-profilegrid-elementor-groups-widget-deactivator.php';
                
		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-profilegrid-elementor-groups-widget-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-profilegrid-elementor-groups-widget-public.php'; 
               
                $this->loader = new Profilegrid_elementor_groups_widget_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Profilegrid_elementor_groups_widget_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {
		$plugin_i18n = new Profilegrid_elementor_groups_widget_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private

	 */
	private function define_admin_hooks() {

		$plugin_admin = new Profilegrid_elementor_groups_widget_Admin( $this->get_Profilegrid_elementor_groups_widget(), $this->get_version(),$this->minimum_elementor_version,$this->minimum_php_version );
		
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
        
                // Check if Elementor installed and activated.
		if ( ! did_action( 'elementor/loaded' ) ) {
			$this->loader->add_action( 'admin_notices', $plugin_admin, 'admin_notice_missing_main_plugin' );
			return;
		}

		// Check for required Elementor version.
		if ( ! version_compare( ELEMENTOR_VERSION,$this->minimum_elementor_version, '>=' ) ) {
			$this->loader->add_action( 'admin_notices', $plugin_admin, 'admin_notice_minimum_elementor_version');
			return;
		}

		// Check for required PHP version.
		if ( version_compare( PHP_VERSION,$this->minimum_php_version, '<' ) ) {
			$this->loader->add_action( 'admin_notices',$plugin_admin, 'admin_notice_minimum_php_version');
			return;
		}
                // Register widgets
               $this->loader->add_action( 'elementor/widgets/widgets_registered',$plugin_admin, 'register_widgets');
               $this->loader->add_action( 'admin_menu', $plugin_admin, 'profilegrid_groups_widget_admin_menu' );
        	   $this->loader->add_action( 'profile_magic_setting_option', $plugin_admin, 'profilegrid_elementor_widget_add_option_setting_page');  
        	   $this->loader->add_action( 'elementor/elements/categories_registered',$plugin_admin, 'add_elementor_widget_categories' );     
        }

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {
            $plugin_public = new Profilegrid_elementor_groups_widget_Public( $this->get_Profilegrid_elementor_groups_widget(), $this->get_version() );
            $this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles',999999999999 );
            $this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts',9999999999999999 );
            $this->loader->add_action('wp_ajax_pm_get_all_groups_widget', $plugin_public, 'pm_get_all_groups_widget');
		    $this->loader->add_action('wp_ajax_nopriv_pm_get_all_groups_widget', $plugin_public, 'pm_get_all_groups_widget');

		    $this->loader->add_action('wp_ajax_pm_get_all_users_widget', $plugin_public, 'pm_get_all_users_widget');
		    $this->loader->add_action('wp_ajax_nopriv_pm_get_all_users_widget', $plugin_public, 'pm_get_all_users_widget');
   }

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_Profilegrid_elementor_groups_widget() {
		return $this->Profilegrid_elementor_groups_widget;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Profilegrid_elementor_groups_widget_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

        
	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
