<?php
/**
 * Elementor oEmbed Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Elementor_PG_Widget_Users extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve oEmbed widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'profilegridelementorusers';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve oEmbed widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Profilegrid Users', 'profilegrid-elementor-groups-widget' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve oEmbed widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-user-circle-o';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the oEmbed widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'profile-grid' ];
	}

	/**
	 * Register Profilegrid Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
            

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Profilegrid Users', 'profilegrid-elementor-groups-widget' ),
				'tab' 	=> \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$dbhandler = new PM_DBhandler;
        $groups = $dbhandler->get_all_result('GROUPS');
        foreach($groups as $group){
            $ids = $group->id;
            $options[$ids] = $group->group_name;
        }

        $args = array('orderby' => 'display_name');
		$wp_user_query = new WP_User_Query($args);
		$users = $wp_user_query->get_results();
		$usersList = array();
        foreach ($users as $user) {
        	$usersList[$user->ID] = $user->display_name; 
        }

		$this->add_control(
			'pg_elementor_users',
			[
				'label' 	=> __( 'Select Users', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> 'all',
				'options' 	=> [
					'all'  	=> __( 'All Groups Users', 'profilegrid-elementor-groups-widget' ),
					'sel' 	=> __( 'Selected Group User', 'profilegrid-elementor-groups-widget' ),
					'user'	=> __( 'Select Users', 'profilegrid-elementor-groups-widget')
				],
			]
		);
		$this->add_control(
			'pg_elementor_user_widget_list',
			[
				'label' => __( 'Select the Groups', 'profilegrid-elementor-groups-widget' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'options' => $options,
				'multiple' => false,
				'default'=>'',
                'condition'    => ['pg_elementor_users' => 'sel'],
			]
		);

		$this->add_control(
			'pg_elementor_users_widget_list',
			[
				'label' => __( 'Select the Users', 'profilegrid-elementor-groups-widget' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'options' => $usersList,
				'multiple' => true,
				'default'=>'',
                'condition'    => ['pg_elementor_users' => 'user'],
			]
		);
		$this->add_control(
			'pg_elementor_user_count',
			[
				'label' 	=> __( 'Number Of Users per page', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::NUMBER,
				'min' 		=> 1,
				'max' 		=> 100,
				'step' 		=> 1,
				'default' 	=> 20,
				'condition'	=> [
					'pg_elementor_users' => [ 'all', 'sel' ]
				]
			]
		);
		/* $this->add_control(
			'pg_elementor_users_view_type',
			[
				'label' 	=> __( 'View Type', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> 'grid',
				'options' 	=> [
					'grid'  => __( 'Grid View', 'profilegrid-elementor-groups-widget' ),
					'list' 	=> __( 'List View', 'profilegrid-elementor-groups-widget' )
				],
			]
		); */
		$this->add_control(
			'pg_elementor_users_grid_column',
			[
				'label' 	=> __( 'Desktop Column Per Row', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::NUMBER,
				'min' 		=> 1,
				'max' 		=> 10,
				'step' 		=> 1,
				'default' 	=> 5
			]
		);
		$this->add_control(
			'pg_elementor_mb_users_grid_column',
			[
				'label' 	=> __( 'Mobile Column Per Row', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::NUMBER,
				'min' 		=> 1,
				'max' 		=> 5,
				'step' 		=> 1,
				'default' 	=> 2
				
			]
		);
		$this->add_control(
			'pg_elementor_user_sort_by',
			[
				'label' 	=> __( 'Sort By', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> 'latest_first',
				'options' 	=> [
					'latest_first'  	=> __( 'Newest', 'profilegrid-elementor-groups-widget' ),
					'oldest_first' 		=> __( 'Oldest', 'profilegrid-elementor-groups-widget' ),
					'first_name_asc'  	=> __( 'First Name Alphabetically A - Z', 'profilegrid-elementor-groups-widget' ),
					'first_name_desc' 	=> __( 'First Name Alphabetically Z - A', 'profilegrid-elementor-groups-widget' ),
					'last_name_asc'		=> __( 'Last Name Alphabetically A - Z', 'profilegrid-elementor-groups-widget'  ),
					'last_name_desc'	=> __( 'Last Name Alphabetically Z- A', 'profilegrid-elementor-groups-widget' )
				],
			]
		);


		$this->end_controls_section();


		$this->start_controls_section(
				'style_section',
				[
					'label' => __( 'Style Card', 'profilegrid-elementor-groups-widget' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);
		$this->add_control(
			'pg_elementor_users_title_text_align',
			[
				'label' => __( 'Alignment', 'profilegrid-elementor-groups-widget' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'profilegrid-elementor-groups-widget' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'profilegrid-elementor-groups-widget' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'profilegrid-elementor-groups-widget' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
			]
		);
		$this->add_control(
			'pg_elementor_users_button_color',
			[
				'label' => __( 'Button Background', 'profilegrid-elementor-groups-widget' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => Elementor\Core\Schemes\Color::get_type(),
					'value' => Elementor\Core\Schemes\Color::COLOR_1,
				],
				'default'	=> '#0170B9',
				'selectors' => [
					'{{WRAPPER}} .title' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'pg_elementor_user_desc_setting',
			[
				'label' => __( 'Show Description', 'profilegrid-elementor-groups-widget'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'profilegrid-elementor-groups-widget' ),
				'label_off' => __( 'Hide', 'profilegrid-elementor-groups-widget' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render oEmbed widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings 				= $this->get_settings_for_display();
		$dbhandler 				= new PM_DBhandler;
		$pmrequest 				= new PM_request;
		$pgwidgetpublic 		= new Profilegrid_elementor_groups_widget_Public('','');
		$view 					= 'grid';
		$view_column 			= $view == 'grid' ? 'user-db-grid-column-'.$settings['pg_elementor_users_grid_column'] : 'user-db-list-column-1';
		$view_column_mb			= $view == 'grid' ? 'user-mb-grid-column-'.$settings['pg_elementor_mb_users_grid_column'] : 'user-db-list-column-1';
		$pagenum 				= 1;
		$sortby 				= $settings['pg_elementor_user_sort_by'];
		$gid 					= $settings['pg_elementor_user_widget_list'];
		$limit					= $settings['pg_elementor_user_count'];
		$selectedUsers 			= $settings['pg_elementor_users_widget_list'];


		// Style

		$style=array();
		$style['button'] = $settings['pg_elementor_users_button_color'];
		$style['alignment'] = $settings['pg_elementor_users_title_text_align'];
		$style['description'] = $settings['pg_elementor_user_desc_setting']=='yes' ? $settings['pg_elementor_user_desc_setting'] : 'no';

		echo '<div class="pmagic">';
		echo '<style type="text/css">
		.elementor-element-'.$this->get_id().' .elementor-users-widget-container .user-title{text-align:'.$style['alignment'].';}
		.elementor-element-'.$this->get_id().' .elementor-users-widget-container .el-profile-action button{background-color:'.$style['button'].';}
		</style>';
		echo '<div id="pm_result_pane_user" class="elementor-users-widget-container '.$view_column.' '.$view_column_mb.'">';
			if($settings['pg_elementor_users']=='user'){
				$pgwidgetpublic->pm_get_users_by_id_widget($selectedUsers,$view, $style);
			} else{
				$pgwidgetpublic->pm_advance_user_widget_html($pagenum, $sortby, $gid, $limit, $view,$style);
			}
			
		echo '</div>';
		echo '</div>';


		
        
	}

}