<?php
/**
 * Elementor oEmbed Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Elementor_PG_Groups_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve oEmbed widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'profilegridelementorgroups';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve oEmbed widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Profilegrid Groups', 'profilegrid-elementor-groups-widget' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve oEmbed widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the oEmbed widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'profile-grid' ];
	}

	/**
	 * Register Profilegrid Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
            

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Profilegrid Groups', 'profilegrid-elementor-groups-widget' ),
				'tab' 	=> \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$dbhandler = new PM_DBhandler;
        $groups = $dbhandler->get_all_result('GROUPS');
        foreach($groups as $group){
            $ids = $group->id;
            $options[$ids] = $group->group_name;
        }

		$this->add_control(
			'pg_elementor_groups',
			[
				'label' 	=> __( 'Select groups', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> 'all',
				'options' 	=> [
					'all'  => __( 'All Groups', 'profilegrid-elementor-groups-widget' ),
					'sel' 	=> __( 'Select Groups', 'profilegrid-elementor-groups-widget' )
				],
			]
		);
		$this->add_control(
			'pg_elementor_groups_widget_list',
			[
				'label' => __( 'Select the User Group', 'profilegrid-elementor-groups-widget' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'options' => $options,
				'multiple' => true,
				'default'=>'',
                'condition'    => ['pg_elementor_groups' => 'sel'],
			]
		);
		$this->add_control(
			'pg_elementor_groups_count',
			[
				'label' 	=> __( 'Number Of Groups per page', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::NUMBER,
				'min' 		=> 1,
				'max' 		=> 10,
				'step' 		=> 1,
				'default' 	=> 5,
				'condition'    => ['pg_elementor_groups' => 'all'],
			]
		);
		$this->add_control(
			'pg_elementor_view_type',
			[
				'label' 	=> __( 'View Type', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> 'grid',
				'options' 	=> [
					'grid'  => __( 'Grid View', 'profilegrid-elementor-groups-widget' ),
					'list' 	=> __( 'List View', 'profilegrid-elementor-groups-widget' )
				],
			]
		);
		$this->add_control(
			'pg_elementor_grid_column',
			[
				'label' 	=> __( 'Desktop Column Per Row', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::NUMBER,
				'min' 		=> 1,
				'max' 		=> 5,
				'step' 		=> 1,
				'default' 	=> 2,
				'condition'    => ['pg_elementor_view_type' => 'grid'],
			]
		);
		$this->add_control(
			'pg_elementor_mb_grid_column',
			[
				'label' 	=> __( 'Mobile Column Per Row', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::NUMBER,
				'min' 		=> 1,
				'max' 		=> 5,
				'step' 		=> 1,
				'default' 	=> 2,
				'condition'    => ['pg_elementor_view_type' => 'grid'],
			]
		);
		$this->add_control(
			'pg_elementor_sort_by',
			[
				'label' 	=> __( 'Sort By', 'profilegrid-elementor-groups-widget' ),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> 'newest',
				'options' 	=> [
					'newest'  	=> __( 'Newest', 'profilegrid-elementor-groups-widget' ),
					'oldest' 	=> __( 'Oldest', 'profilegrid-elementor-groups-widget' ),
					'name_asc'  => __( 'Alphabetical (A-Z)', 'profilegrid-elementor-groups-widget' ),
					'name_desc' => __( 'Alphabetical (Z-A)', 'profilegrid-elementor-groups-widget' )
				],
			]
		);


		$this->end_controls_section();


		$this->start_controls_section(
				'style_section',
				[
					'label' => __( 'Style Card', 'profilegrid-elementor-groups-widget' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);
		$this->add_control(
			'pg_elementor_group_title_text_align',
			[
				'label' => __( 'Alignment', 'profilegrid-elementor-groups-widget' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'profilegrid-elementor-groups-widget' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'profilegrid-elementor-groups-widget' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'profilegrid-elementor-groups-widget' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
			]
		);
		$this->add_control(
			'pg_elementor_groups_button_color',
			[
				'label' => __( 'Button Background', 'profilegrid-elementor-groups-widget' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => Elementor\Core\Schemes\Color::get_type(),
					'value' => Elementor\Core\Schemes\Color::COLOR_1,
				],
				'default'	=> '#0170B9',
				'selectors' => [
					'{{WRAPPER}} .pm_button button' => 'background-color: {{VALUE}}',
				],
			]
		);
                
                $this->add_control(
			'pg_elementor_groups_button_text_color',
			[
				'label' => __( 'Button Text Color', 'profilegrid-elementor-groups-widget' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => Elementor\Core\Schemes\Color::get_type(),
					'value' => Elementor\Core\Schemes\Color::COLOR_1,
				],
				'default'	=> '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .pm_button button' => 'color: {{VALUE}}',
				],
			]
		);
                
		$this->add_control(
			'pg_elementor_groups_desc_setting',
			[
				'label' => __( 'Show Description', 'profilegrid-elementor-groups-widget' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'profilegrid-elementor-groups-widget' ),
				'label_off' => __( 'Hide', 'profilegrid-elementor-groups-widget' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render oEmbed widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings 				= $this->get_settings_for_display();
		$dbhandler 				= new PM_DBhandler;
		$pmrequest 				= new PM_request;

		$pgwidgetpublic 		= new Profilegrid_elementor_groups_widget_Public('','');
		$view 					= $settings['pg_elementor_view_type'];
		$column 				= $view=='grid' ? 'db-grid-column-'.$settings['pg_elementor_grid_column'] : 'list-column-1';
		$mbcolumn 				= $view=='grid' ? 'mb-grid-column-'.$settings['pg_elementor_mb_grid_column'] : 'list-column-1';
		$sort_by 				= $settings['pg_elementor_sort_by'];
		$search 				='';
		$pagenum 				= 1;
		$limit 					= $settings['pg_elementor_groups_count'] ? $settings['pg_elementor_groups_count']:1;
		$grid_text_align 		= $settings['pg_elementor_group_title_text_align'] ? $settings['pg_elementor_group_title_text_align'] : 'center';
		$list_text_align 		= $settings['pg_elementor_group_title_text_align'] ? $settings['pg_elementor_group_title_text_align'] : 'left';
		$btnbg 					= $settings['pg_elementor_groups_button_color'];
		$btntxtcolor 					= $settings['pg_elementor_groups_button_text_color'];
		
                $short_desc 			= $settings['pg_elementor_groups_desc_setting'];
		echo '<div class="pmagic elementor-phmagic">';
		echo '<style type="text/css">
		.elementor-element-'.$this->get_id().' .view-type-grid .pm-group-heading{text-align:'.$grid_text_align.';}
		.elementor-element-'.$this->get_id().' .view-type-list .pm-group-heading{text-align:'.$list_text_align.';}
		.elementor-element-'.$this->get_id().' a.pm_button button{background-color:'.$btnbg.';}
                 .elementor-element-'.$this->get_id().' a.pm_button button{color:'.$btntxtcolor.';}
		</style>';
		echo '<div class="elementor-pg-group-container pm-group-container pm-dbfl pm-groups-widget-content view-type-'.$view.'" >';
		echo '<div class="pm-all-group-container pm-dbfl '.$column.' '.$mbcolumn.' ">';
		if($settings['pg_elementor_groups'] == 'all'){
			$groups = $pgwidgetpublic->pg_get_all_groups_widget_data($view,$pagenum,$limit,$sort_by,$search,$short_desc);
		}
		else{
			$gids = $settings['pg_elementor_groups_widget_list'];
			if(!empty($gids)):
				foreach($gids as $gid)
		        {
		            if(!empty($gid)):
		            $groups = $pgwidgetpublic->pm_get_individual_group_object($gid);
			            if(count($groups) >=1):
				            foreach ($groups as $group):
				            	$pgwidgetpublic->pm_get_group_widget_html($group,$view,$short_desc);
				            endforeach;
				        endif;
		            endif;
		        }
		    endif;
			
		}
		echo '</div></div>';
		echo '</div>';
		

	}

}