<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://profilegrid.co
 * @since      1.0.0
 *
 * @package    Profilegrid_elementor_groups_widget
 * @subpackage Profilegrid_elementor_groups_widget/public
 */
/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Profilegrid_elementor_content_restrictions
 * @subpackage Profilegrid_elementor_groups_widget/public
 * @author     profilegrid
 */


class Profilegrid_elementor_groups_widget_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $Profilegrid_elementor_groups_widget    The ID of this plugin.
     */
    private $Profilegrid_elementor_groups_widget;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $Profilegrid_elementor_groups_widget       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($Profilegrid_elementor_groups_widget, $version) {

        $this->Profilegrid_elementor_groups_widget = $Profilegrid_elementor_groups_widget;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Profilegrid_elementor_groups_widget_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Profilegrid_elementor_groups_widget_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style($this->Profilegrid_elementor_groups_widget, plugin_dir_url(__FILE__) . 'css/profilegrid-elementor-groups-widget-public.css', array(), $this->version, 'all');
      
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Profilegrid_elementor_groups_widget_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Profilegrid_elementor_groups_widget_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script('jquery');
        wp_enqueue_script($this->Profilegrid_elementor_groups_widget, plugin_dir_url(__FILE__) . 'js/profilegrid-elementor-groups-widget-public.js', array(), $this->version, true);
        
    }
    
    public function pm_get_all_groups_widget()
    {
        $sort_by = filter_input(INPUT_POST, 'sortby');
        $search = filter_input(INPUT_POST, 'search');
        $pagenum = filter_input(INPUT_POST, 'pagenum');
        $limit = filter_input(INPUT_POST,'limit');
        $view = filter_input(INPUT_POST, 'view');
        $this->pg_get_all_groups_widget_data($view,$pagenum,$limit,$sort_by,$search,$this->Profilegrid_elementor_groups_widget,$this->version);
        
        die;
    }
    public function pm_get_all_users_widget()
    {
        $sort_by = filter_input(INPUT_POST, 'member_sort_by');
        $pagenum = filter_input(INPUT_POST, 'pagenum');
        $limit = filter_input(INPUT_POST,'limit');
        $gid = filter_input(INPUT_POST, 'gid');
        $view = filter_input(INPUT_POST,'view');
        $style['description'] = filter_input(INPUT_POST,'description');    
        $this->pm_advance_user_widget_html($pagenum,$sort_by,$gid,$limit,$view,$style,$this->Profilegrid_elementor_groups_widget,$this->version);
        
        die;
    }
    public function pg_get_all_groups_widget_data($view='grid',$pagenum=1,$limit=10,$sort_by='newest',$search='',$short_desc){
        $dbhandler = new PM_DBhandler;
        $offset = ( $pagenum - 1 ) * $limit;
      
        $search_str = trim($search);
        if($search_str!='')
        {
            $is_search = true;
            $additional = "group_name like '".$search_str."%'";
        }
        else 
        {
            $is_search = false;
            $additional = '';
        }
        
        $additional = apply_filters('pm_get_all_groups_data_additional', $additional);
        
        switch($sort_by)
        {
            case 'newest':
                $sortby = 'id';
                $order = 'DESC';
                break;
             case 'oldest':
                $sortby = 'id';
                $order = false;
                break;
            case 'name_asc':
                $sortby = 'group_name';
                $order = false;
                break;
            case 'name_desc':
                $sortby = 'group_name';
                $order = 'DESC';
                break;
            default:
                $sortby = 'id';
                $order = 'DESC';
                break;
            
        }
        
        
        $groups =  $dbhandler->get_all_result('GROUPS','*',1,'results',$offset,$limit,$sortby,$order,$additional);
        $total_groups = count($dbhandler->get_all_result('GROUPS','*',1,'results',0,false,null,false,$additional));
        
        $num_of_pages = ceil( $total_groups/$limit);
        $pagination = $dbhandler->pm_get_pagination($num_of_pages,$pagenum);
        
        if(!empty($groups))
        { 
            foreach($groups as $group):
                $this->pm_get_group_widget_html($group,$view,$short_desc);
            endforeach;

        }
        elseif(!empty($is_search)) 
        {
        ?> 
         <div class='pg-alert-warning pg-alert-info'><?php _e('No group matches found.',"profilegrid-elementor-groups-widget"); ?></div>
             <?php }else
             {
                ?> 
         <div class='pg-alert-warning pg-alert-info'><?php _e('There are not created any groups yet. Once admin have created a new group, it will appear here.',"profilegrid-elementor-groups-widget"); ?></div>
             <?php 
             }
             
             ?>
         <div class="pm_clear"></div>
            <?php
            
            echo '<div class="groups-widget-pagination" data-limit="'.$limit.'" data-sort="'.$sort_by.'" data-view="'.$view.'">'.$pagination.'</div>';
            
       
    }
    public function pm_get_individual_group_object($gid){
        global $wpdb;
        $pm_activator = new Profile_Magic_Activator;
        $table = $pm_activator->get_db_table_name("GROUPS");
        $output ="OBJECT";
        $qry = "SELECT * from ".$table." WHERE id=".$gid;
        return $results = $wpdb->get_results($qry,$output);
    }
    public function pm_get_group_widget_html($group,$view='grid', $short_desc)
    {
        $dbhandler = new PM_DBhandler;
        $pmrequest = new PM_request;
        $option = 'pm_show_group_on_groups_page_'.$group->id;
        if($dbhandler->get_global_option_value($option,'1')=='1')
        {
            if($view=='grid')
            {

                $group_url  = $pmrequest->profile_magic_get_frontend_url('pm_group_page','',$group->id);
                $group_url = add_query_arg( 'gid',$group->id, $group_url );
                $registration_url  = $pmrequest->profile_magic_get_frontend_url('pm_registration_page','');
                $registration_url = add_query_arg( 'gid',$group->id, $registration_url );
            ?>
                <div class="pm-group-elementor pm-difl pm-border pm-radius5 pm-bg-lt pm50">
                  <div class="pm-group-heading pm-dbfl pm-border-bt pm-pad10 pm-clip"><a href="<?php echo esc_url( $group_url ); ?>"><?php echo $group->group_name;?></a></div>
                  <div class="pm-group-info pm-dbfl">
                    <div class="pm-group-logo pm-dbfl pm-bg pm-border-bt">
                        <div class="pm-group-logo-img">
                        <?php echo $pmrequest->profile_magic_get_group_icon($group); ?>
                        </div>
                        
                        <div class="pm-group-bg">
			  <?php echo $pmrequest->profile_magic_get_group_icon($group); ?>
                        </div>
                    </div>
                    <?php
                                    $groupdesc = '';
                                    if(strlen($group->group_desc) > 150)
                                    {
                                            $groupdesc = substr($group->group_desc, 0, 150);
                                            $groupdesc .= "...";
                                    }
                                    else
                                    {
                                            $groupdesc = $group->group_desc;
                                    }


                            ?>
                    <?php 
                    if($short_desc =='yes'){?>
                        <div class="pm-group-desc pm-dbfl pm-pad10"><?php echo $groupdesc;?></div>
                    <?php }
                    ?>
                  </div>
                  <?php if (!is_user_logged_in()):?> 
                  <div class="pm-group-button pm-dbfl pm-pad10">
                   <div class="pm-group-signup"><a href="<?php echo $registration_url;?>" class="pm_button"><button><?php _e('Join Group',"profilegrid-elementor-groups-widget");?></button></a></div>
                    <?php if($pmrequest->profile_magic_check_paid_group($group->id)>0):?>
                    <div class="pm_group_price">
                      <?php if($dbhandler->get_global_option_value('pm_currency_position','before')=='before'):
                            echo $pmrequest->pm_get_currency_symbol().' '.$pmrequest->profile_magic_check_paid_group($group->id);
                        else:
                            echo $pmrequest->profile_magic_check_paid_group($group->id).' '.$pmrequest->pm_get_currency_symbol();
                        endif;
                        ?>
                    </div>
                    <?php else: ?>
                    <div class="pm_free_group"><?php _e('Free',"profilegrid-elementor-groups-widget");?></div>
                    <?php endif; ?>
                    </div>
                   <?php else: ?>
                  <div class="pm-group-button pm-dbfl pm-pad10">
                   <div class="pm-group-signup">
                       <a href="<?php echo $group_url;?>" class="pm_button">
                           <button><?php _e('Details',"profilegrid-elementor-groups-widget");?></button>
                       </a>
                   </div>
                  </div>
                  <?php endif;?>
                </div>
                <?php   
            }
            else
            {
                 $group_url  = $pmrequest->profile_magic_get_frontend_url('pm_group_page','',$group->id);
                $group_url = add_query_arg( 'gid',$group->id, $group_url );
                $registration_url  = $pmrequest->profile_magic_get_frontend_url('pm_registration_page','');
                $registration_url = add_query_arg( 'gid',$group->id, $registration_url );
                $group_type = ($pmrequest->profile_magic_get_group_type($group->id)=='open'? __('Public',"profilegrid-elementor-groups-widget"):__('Private',"profilegrid-elementor-groups-widget"));
                $group_leaders = $pmrequest->pg_get_group_leaders($group->id);
                ?>
         <div class="pm-group-list-view pm-dbfl">
             <div class="pm-group-logo pm-difl"> <?php echo $pmrequest->profile_magic_get_group_icon($group,'pm-group-badge'); ?></div>
             <div class="pm-group-name-desc pm-difl">
                 <div class="pm-group-heading pm-dbfl pm-pad10 pm-clip"><a href="<?php echo esc_url( $group_url ); ?>"><?php echo $group->group_name;?></a></div>
                 <?php
                                    $groupdesc = '';
                                    if(strlen($group->group_desc) > 150)
                                    {
                                            $groupdesc = substr($group->group_desc, 0, 150);
                                            $groupdesc .= "...";
                                    }
                                    else
                                    {
                                            $groupdesc = $group->group_desc;
                                    }


                            ?>
                    <?php if($short_desc =='yes'){?>        
                    <div class="pm-group-desc pm-dbfl pm-pad10"><?php echo $groupdesc;?></div>
                    <?php } ?>
                    <div class="pm-element-group-list-view-info"><?php echo $group_type;?> / <a> <span><?php echo count($group_leaders);?></span></a> <?php echo $pmrequest->pm_get_group_admin_label($group->id);?> / <a><span><?php echo $pmrequest->pm_count_group_members($group->id);?></span></a> <?php _e('Members',"profilegrid-elementor-groups-widget");?></div>
             </div>
             <div class="pm-group-button pm-difr">

                  <?php if (!is_user_logged_in()):?> 
                  <div class="pm-group-button pm-dbfl pm-pad10">
                   <div class="pm-group-signup"><a href="<?php echo $registration_url;?>" class="pm_button"><button><?php _e('Join Group',"profilegrid-elementor-groups-widget");?></button></a></div>
                    <?php if($pmrequest->profile_magic_check_paid_group($group->id)>0):?>
                    <div class="pm_group_price">
                      <?php if($dbhandler->get_global_option_value('pm_currency_position','before')=='before'):
                            echo $pmrequest->pm_get_currency_symbol().' '.$pmrequest->profile_magic_check_paid_group($group->id);
                        else:
                            echo $pmrequest->profile_magic_check_paid_group($group->id).' '.$pmrequest->pm_get_currency_symbol();
                        endif;
                        ?>
                    </div>
                    <?php else: ?>
                    <div class="pm_free_group"><?php _e('Free',"profilegrid-elementor-groups-widget");?></div>
                    <?php endif; ?>
                    </div>
                   <?php else: ?>
                  <div class="pm-group-button pm-dbfl pm-pad10">
                   <div class="pm-group-signup">
                       <a href="<?php echo $group_url;?>" class="pm_button">
                           <button><?php _e('Details',"profilegrid-elementor-groups-widget");?></button>
                       </a>
                   </div>
                  </div>
                  <?php endif;?>
             </div>

         </div>
         <?php

            }
        }
    }
    
    public function pm_advance_user_widget_html($pagenum, $sortby, $gid, $limit, $view="grid", $style=array())
    {       
            $dbhandler = new PM_DBhandler;
            $pmrequests = new PM_request;
            $sortbydata = $sortby;
            switch($sortby)
            {
                case 'name_asc':
                    $sortby = 'display_name';
                    $order = 'ASC';
                    break;
                case 'name_desc':
                    $sortby = 'display_name';
                    $order = 'DESC';
                    break;
                case 'latest_first':
                    $sortby = 'registered';
                    $order = 'DESC';
                    break;
                 case 'oldest_first':
                    $sortby = 'registered';
                    $order = 'ASC';
                    break;
                case 'suspended':
                    $sortby = 'registered';
                    $order = 'DESC';
                    $get['status'] = '1';
                    break;
                case 'first_name_asc':
                    $sortby = 'first_name';
                    $order = 'ASC';
                    break;
                case 'first_name_desc':
                    $sortby = 'first_name';
                    $order = 'DESC';
                    break;
                case 'last_name_asc':
                    $sortby = 'last_name';
                    $order = 'ASC';
                    break;
                case 'last_name_desc':
                    $sortby = 'last_name';
                    $order = 'DESC';
                    break;
                default:
                    $sortby = 'display_name';
                    $order = 'ASC';
                    break;

            }
            $selection = array('pagenum'=> $pagenum,
                               'status' => 0,
                               'member_sort_by'=>$sortby,
                               'gid'    => $gid
                                );
            if(isset($_POST['match_fields']))
            {
           
                $search = '';
                $meta_query_array = $pmrequests->pm_get_user_advance_search_meta_query($selection);
                 
            }
            else
            {   $search = '';
                $meta_query_array = $pmrequests->pm_get_user_meta_query($selection);
            
            }

            $pagenum = isset($pagenum) ? absint($pagenum) : 1;
            $offset = ( $pagenum - 1 ) * $limit;
            $date_query = $pmrequests->pm_get_user_date_query($selection);
            $exclude = $pmrequests->pm_get_hide_users_array();
            $user_query =  $dbhandler->pm_get_all_users_ajax($search,$meta_query_array,'',$offset,$limit,$order,$sortby,$exclude,$date_query);
            $total_users = $user_query->get_total();
            $users = $user_query->get_results();
            $num_of_pages = ceil( $total_users/$limit);
            $pagination = $dbhandler->pm_get_pagination($num_of_pages,$pagenum);
            $user_info =array();
            $return = '';
            
            $return .= '<div class="pg-elementor-users-list">';
            if(!empty($users)){
                foreach($users as $user){       
                        $user_info['avatar']        = get_avatar($user->user_email, 100, '', false, array('class' => 'pm-user-profile','force_display'=>true));
                        $user_info['id']            = $user->ID;
                        $profile_url                = $pmrequests->pm_get_user_profile_url($user->ID);
                        $user_info['profile_url']   = $profile_url;
                        $user_info['name']          = $pmrequests->pm_get_display_name($user->ID,true); 
                        $user_info['bio']           = $style['description'] ? get_user_meta($user->ID, 'description', true) : '';
                        $group_leader_class         = "";
                        
                        if($view=="grid"){
                        $return .= "<div id=\"search_result\" class='pm-user pm-difl pm-radius5 pm-border user-".$view."-view' >
                            <div class='el-profile-avatar'>".$user_info['avatar']."</div>
                                    <div class='el-profile-details'><div class='user-title'><a href=".$user_info['profile_url'].">".$user_info['name']."</a></div></div>
                                    
                        </div>";
                        } else{
                            $return .= "<div id='search_result' class='pm-user pm-difl pm-radius5 pm-border user-".$view."-view'>
                                    <div class='el-profile-avatar'>".$user_info['avatar']."</div>
                                    <div class='el-profile-details'><div class='user-title'><a href=".$user_info['profile_url'].">".$user_info['name']."</a></div><div class='el-bio'>".$user_info['bio']."</div></div>
                                    <div class='el-profile-action'><a href=".$user_info['profile_url']." class='pm_button'><button>View Profile</button></a></div>
                                </div>";
                        }
                }

            }
            else{
                    $return ="<div class=\"pm-message pm-dbfl pm-pad10\">"
                            . __("Sorry, No Users Found.." ,"profilegrid-elementor-groups-widget")
                            ."</div>";
            }
              
            $return .= '</div>';
                if(isset($pagination))
                $return.="<div class=\"pm_clear\"></div><div class='elementor-user-widget-pagination' data-gid='".$gid."' data-limit='".$limit."' data-sortby='".$sortbydata."' data-view='".$view."' data-description='".$style["description"]."'>".$pagination."</div>";
           
              echo $return;
            
    }
    
    public function pm_get_users_by_id_widget($usersID= array(), $view='grid', $style=array()){
        $pmrequests = new PM_request;
        $return = '<div class="pg-elementor-users-list">';
        foreach($usersID as $id){
            $user = get_user_by( 'id', $id );
            $user_info['avatar']        = get_avatar($user->user_email, 100, '', false, array('class' => 'pm-user-profile','force_display'=>true));
            $user_info['id']            = $user->ID;
            $profile_url                = $pmrequests->pm_get_user_profile_url($user->ID);
            $user_info['profile_url']   = $profile_url;
            $user_info['name']          = $pmrequests->pm_get_display_name($user->ID,true); 
            $user_info['bio']           = $style['description']=='yes' ? get_user_meta($user->ID, 'description', true) : '';
            $group_leader_class         = "";
            $title_alignment            = $style['alignment'] ? $style['alignment'] : 'center';
           
            if($view=='grid'){
                $return .= "<div id=\"search_result\" class='pm-user pm-difl pm-radius5 pm-border user-".$view."-view' >
                            <div class='el-profile-avatar'>".$user_info['avatar']."</div>
                                    <div class='el-profile-details'><div class='user-title'><a href=".$user_info['profile_url'].">".$user_info['name']."</a></div><div class='el-bio'>".$user_info['bio']."</div></div>
                                    <div class='el-profile-action'><a href=".$user_info['profile_url']." class='pm_button'><button>View Profile</button></a></div>
                        </div>";
            }
            else{
                $return .= "<div id='search_result' class='pm-user pm-difl pm-radius5 pm-border user-".$view."-view'>
                        <div class='el-profile-avatar'>".$user_info['avatar']."</div>
                        <div class='el-profile-details'><div class='user-title'><a href=".$user_info['profile_url'].">".$user_info['name']."</a></div><div class='el-bio'>".$user_info['bio']."</div></div>
                        <div class='el-profile-action'><a href=".$user_info['profile_url']." class='pm_button'><button>View Profile</button></a></div>
                    </div>";
            }
        }
        $return .= '</div>'; 
        echo $return;
    }


}
            