<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Profilegrid_User_Activities
 * @subpackage Profilegrid_User_Activities/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Profilegrid_User_Activities
 * @subpackage Profilegrid_User_Activities/admin
 * @author     Your Name <email@example.com>
 */
class Profilegrid_User_Activities_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $profilegrid_user_activities    The ID of this plugin.
	 */
	private $profilegrid_user_activities;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $profilegrid_user_activities       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $profilegrid_user_activities, $version ) {

		$this->profilegrid_user_activities = $profilegrid_user_activities;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_User_Activities_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_User_Activities_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
             if (class_exists('Profile_Magic') ) {
                    wp_enqueue_style( $this->profilegrid_user_activities, plugin_dir_url( __FILE__ ) . 'css/profilegrid-user-activities-admin.css', array(), $this->version, 'all' );

             }
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_User_Activities_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_User_Activities_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
             if (class_exists('Profile_Magic') ) {
                wp_enqueue_script( $this->profilegrid_user_activities, plugin_dir_url( __FILE__ ) . 'js/profilegrid-user-activities-admin.js', array( 'jquery' ), $this->version, false );
            }
	}
        
        public function profilegrid_user_activities_admin_menu()
	{
                add_submenu_page("",__("Display Name Settings","profilegrid-user-activities"),__("Display Name Settings","profilegrid-user-activities"),"manage_options","pm_user_activities_settings",array( $this, 'pm_user_activities_settings' ));
        }
	
        public function pm_user_activities_settings()
        {
            include 'partials/profilegrid-user-activities-admin-display.php';
        }
        
        public function profilegrid_user_activities_add_option_setting_page()
        {
            include 'partials/profilegrid-user-activities-setting-option.php';
        }
        
        public function profile_magic_user_activities_notice_fun()
        {
            if (!class_exists('Profile_Magic') ) {
                    
                $this->User_activities_installation();
                    //wp_die( "ProfileGrid Stripe won't work as unable to locate ProfileGrid plugin files." );
            }
        }
        
        public function User_activities_installation()
        {
            $plugin_slug= 'profilegrid-user-profiles-groups-and-communities';
            $installUrl = admin_url('update.php?action=install-plugin&plugin=' . $plugin_slug);
            $installUrl = wp_nonce_url($installUrl, 'install-plugin_' . $plugin_slug);
            ?>
            <div class="notice notice-success is-dismissible">
                <p><?php echo sprintf(__( "ProfileGrid User Activities work with ProfileGrid Plugin. You can install it  from <a href='%s'>Here</a>.", 'profilegrid-user-activities' ),$installUrl); ?></p>
            </div>
            <?php
             $plugin = trim(basename(plugin_dir_path(dirname( __FILE__))).'/profilegrid-user-activities.php');
            //echo $plugin;
            deactivate_plugins($plugin);
        }
        
      
        
        public function activate_sitewide_plugins($blog_id)
        {
            // Switch to new website
            $dbhandler = new PM_DBhandler;
            $activator = new Profile_Magic_Activator;
            switch_to_blog( $blog_id );
            // Activate
            foreach( array_keys( get_site_option( 'active_sitewide_plugins' ) ) as $plugin ) {
                do_action( 'activate_'  . $plugin, false );
                do_action( 'activate'   . '_plugin', $plugin, false );
                $activator->activate();
                
            }
            // Restore current website 
            restore_current_blog();
        }
        
        public function profile_magic_user_activities_group_option($id,$group_options)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_user_activities','0')==1):
             include 'partials/profilegrid-user-activities-group-option.php';
            endif;
        }
        
        public function pg_load_activities_widget()
        {
             register_widget('Profilegrid_User_Activities_widget');
        }

}
