<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Profilegrid_User_Activities
 * @subpackage Profilegrid_User_Activities/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Profilegrid_User_Activities
 * @subpackage Profilegrid_User_Activities/includes
 * @author     Your Name <email@example.com>
 */
class Profilegrid_User_Activities {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Profilegrid_User_Activities_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $profilegrid_user_activities    The string used to uniquely identify this plugin.
	 */
	protected $profilegrid_user_activities;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->profilegrid_user_activities = 'profilegrid-user-activities';
		$this->version = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Profilegrid_User_Activities_Loader. Orchestrates the hooks of the plugin.
	 * - Profilegrid_User_Activities_i18n. Defines internationalization functionality.
	 * - Profilegrid_User_Activities_Admin. Defines all hooks for the admin area.
	 * - Profilegrid_User_Activities_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
             
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-profilegrid-user-activities-loader.php';
                require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-profilegrid-user-activities-helper.php';
                require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-profilegrid-user-activities-functions.php';
                
		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-profilegrid-user-activities-i18n.php';
                require_once plugin_dir_path(  dirname( __FILE__ )) . 'includes/class-profilegrid-user-activities-activator.php';
                require_once plugin_dir_path( dirname( __FILE__ )   ) . 'includes/class-profilegrid-user-activities-deactivator.php';
                
		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-profilegrid-user-activities-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-profilegrid-user-activities-public.php';
                require_once plugin_dir_path( dirname( __FILE__ ) ) . 'widgets/profilegrid-user-activities-widgets.php';

		
                $this->loader = new Profilegrid_User_Activities_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Profilegrid_User_Activities_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {
		$plugin_i18n = new Profilegrid_User_Activities_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Profilegrid_User_Activities_Admin( $this->get_profilegrid_user_activities(), $this->get_version() );
                $this->loader->add_action( 'widgets_init',$plugin_admin, 'pg_load_activities_widget');
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
                $this->loader->add_action( 'admin_menu', $plugin_admin, 'profilegrid_user_activities_admin_menu' );
                $this->loader->add_action( 'profile_magic_setting_option', $plugin_admin, 'profilegrid_user_activities_add_option_setting_page' );
                $this->loader->add_action( 'admin_notices', $plugin_admin, 'profile_magic_user_activities_notice_fun' );
                $this->loader->add_action( 'network_admin_notices', $plugin_admin, 'profile_magic_user_activities_notice_fun' );
                $this->loader->add_action('wpmu_new_blog', $plugin_admin, 'activate_sitewide_plugins');
        }

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {
            $plugin_public = new Profilegrid_User_Activities_Public( $this->get_profilegrid_user_activities(), $this->get_version() );
            $this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
            $this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
            $this->loader->add_action('profile_magic_join_group_additional_process', $plugin_public,'profilegrid_user_activities_join_group',10,2);
            $this->loader->add_action('publish_profilegrid_blogs', $plugin_public,'profilegrid_user_activities_blog_published',10,2);
             $this->loader->add_action('profilegrid_group_update',$plugin_public,'profilegrid_user_activities_update_group_icon',10,3);
            $this->loader->add_action('pg_user_leave_group', $plugin_public,'profilegrid_user_activities_user_leave_group',10,2);
            $this->loader->add_action('profile_magic_join_group_additional_process', $plugin_public, 'profilegrid_user_activities_group_registration_full',10,2);
            $this->loader->add_action('ProfileGrid_after_create_group',$plugin_public,'profilegrid_user_activities_group_create',10,1 );
            $this->loader->add_action('pm_unassign_group_manager_privilege', $plugin_public,'profilegrid_user_activities_remove_group_manager',10,2);
            $this->loader->add_action('pm_assign_group_manager_privilege', $plugin_public,'profilegrid_user_activities_assign_group_manager',10,2);
            $this->loader->add_action( 'init', $plugin_public, 'register_shortcodes' );   
            // Group Wall
             $this->loader->add_action('publish_pg_groupwalls', $plugin_public,'profilegrid_user_activities_group_wall_published',10,2);
             $this->loader->add_action('comment_post', $plugin_public, 'profilegrid_user_activities_wall_post_comment',10,3);
          // Group Photo
            $this->loader->add_action('pg_user_upload_group_photo', $plugin_public, 'profilegrid_user_activities_group_photo_upload',10,2);
            $this->loader->add_action('pg_user_create_group_album', $plugin_public, 'profilegrid_user_activities_group_album_create',10,2);
             $this->loader->add_action('comment_post', $plugin_public, 'profilegrid_user_activities_group_photo_comment',10,3);
           //bbPress
             $this->loader->add_action('bbp_new_topic_post_extras', $plugin_public, 'profilegrid_user_activities_bbPress_topic_created',10,2);
             $this->loader->add_action('bbp_new_reply_post_extras', $plugin_public, 'profilegrid_user_activities_bbPress_topic_reply',10,2);
          // MyCred
             $this->loader->add_action('mycred_update_user_balance', $plugin_public, 'profilegrid_user_activities_mycred_user_award_points',10,4);
         // Profile Labels
             $this->loader->add_action('pg_user_update_profile_label', $plugin_public, 'profilegrid_user_activities_update_profile_label',10,3);
         // Profile status 
             $this->loader->add_action('pg_user_update_profile_status', $plugin_public, 'profilegrid_user_activities_update_profile_status',10,3);
         // user photo
             $this->loader->add_action('pg_user_upload_new_photo', $plugin_public, 'profilegrid_user_activities_user_photo_upload',10,4);
            $this->loader->add_action('pg_user_create_new_album', $plugin_public, 'profilegrid_user_activities_create_user_album',10,4);
        }

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_profilegrid_user_activities() {
		return $this->profilegrid_user_activities;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Profilegrid_User_Activities_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}