<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Profilegrid_User_Activities
 * @subpackage Profilegrid_User_Activities/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Profilegrid_User_Activities
 * @subpackage Profilegrid_User_Activities/public
 * @author     Your Name <email@example.com>
 */
class Profilegrid_User_Activities_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $profilegrid_user_activities    The ID of this plugin.
	 */
	private $profilegrid_user_activities;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $profilegrid_user_activities       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $profilegrid_user_activities, $version ) {

		$this->profilegrid_user_activities = $profilegrid_user_activities;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_User_Activities_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_User_Activities_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->profilegrid_user_activities, plugin_dir_url( __FILE__ ) . 'css/profilegrid-user-activities-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_User_Activities_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_User_Activities_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
                wp_enqueue_script( $this->profilegrid_user_activities, plugin_dir_url( __FILE__ ) . 'js/profilegrid-user-activities-public.js', array( 'jquery' ), $this->version, false );
             
	}
        
        public function pg_add_user_activities($gid,$uid,$type,$activities,$meta=array())
        {
            $dbhandler = new PM_DBhandler;
            $identifier = 'ACTIVITIES';
            $time = date("Y-m-d h:i:s");
            $data = array('gid'=>$gid,'uid'=>$uid,'type'=>$type,'activities'=>$activities,'meta'=>maybe_serialize($meta),'timestamp'=>$time);
            $format = array('%d','%d','%s','%s','%s','%s');
            $activities_id = $dbhandler->insert_row($identifier, $data, $format);
            //return $activities_id;            
        }
        
        public function profilegrid_user_activities_join_group($gid,$uid)
        {
           $dbhandler = new PM_DBhandler;
           $pmrequests = new PM_request;
           if($dbhandler->get_global_option_value('pm_enable_registration_activities','0')==1):
            $display_name = $pmrequests->pm_get_display_name($uid);
            $profile_url = $pmrequests->pm_get_user_profile_url($uid);
            $type = 'group';
            $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('joined the Group','profilegrid-user-activities');
            $this->pg_add_user_activities($gid,$uid,$type,$activities);
           endif;
        }
        
        public function profilegrid_user_activities_group_wall_published($ID, $post)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_wall_post_created_activities','0')==1):
                $pmrequests = new PM_request;
                $uid = $post->post_author; /* Post author ID. */
                $gids = $pmrequests->profile_magic_get_user_field_value($uid,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }

                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $post_link = get_permalink($ID);
                $meta = array('post_id'=>$ID);
                $type = 'group_wall';
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('created a','profilegrid-user-activities').' '.'<a href="'.$post_link.'">'.__('new post','profilegrid-user-activities').'</a>';
                $this->pg_add_user_activities($groupid,$uid,$type,$activities,$meta);
            endif;
        }


        public function profilegrid_user_activities_blog_published($ID, $post)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_blog_post_published_activities','0')==1):
                $pmrequests = new PM_request;
                $uid = $post->post_author; /* Post author ID. */
                $gids = $pmrequests->profile_magic_get_user_field_value($uid,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }

                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $post_title = get_the_title($ID);
                $post_link = get_permalink($ID);
                $meta = array('post_id'=>$ID);
                $type = 'blog';
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('published a new post','profilegrid-user-activities').' '.'<a href="'.$post_link.'">'.$post_title.'</a>';
                $this->pg_add_user_activities($groupid,$uid,$type,$activities,$meta);
            endif;
        }
        
        public function profilegrid_user_activities_group_photo_upload($album_id,$uid)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_group_photo_upload_activities','0')==1):
                $pmrequests = new PM_request;
                $identifier = 'ALBUMS';
                $where = 1;
                $additional = "aid = $album_id";
                $album = $dbhandler->get_row($identifier,$album_id);
                $gid = $album->gid;
                $group_url  = $pmrequests->profile_magic_get_frontend_url('pm_group_page','',$gid);
                $group_url = add_query_arg( 'gid',$gid, $group_url );

                $group_name = $dbhandler->get_value('GROUPS','group_name', $gid);
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $type = 'group';
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('added a new photo to','profilegrid-user-activities').' '.'<a href="'.$group_url.'">'.$group_name.'</a>';
                $this->pg_add_user_activities($gid,$uid,$type,$activities);
            endif;
        }
        
        public function profilegrid_user_activities_group_album_create($album_id,$uid)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_group_album_create_activities','0')==1):
                $pmrequests = new PM_request;
                $identifier = 'ALBUMS';
                $where = 1;
                $additional = "aid = $album_id";
                $album = $dbhandler->get_row($identifier,$album_id);
                $gid = $album->gid;
                $group_url  = $pmrequests->profile_magic_get_frontend_url('pm_group_page','',$gid);
                $group_url = add_query_arg( 'gid',$gid, $group_url );

                $group_name = $dbhandler->get_value('GROUPS','group_name', $gid);
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $type = 'group';
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('created a album for group ','profilegrid-user-activities').' '.'<a href="'.$group_url.'">'.$group_name.'</a>';
                $this->pg_add_user_activities($gid,$uid,$type,$activities);
            endif;
        }
      
        public function profilegrid_user_activities_wall_post_comment($comment_ID, $comment_approved,$comment)
        {
            //print_r($comment);
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_comment_on_wall_post_activities','0')==1):
                $pmrequests = new PM_request;
                $postid = $comment['comment_post_ID'];
                $uid = $comment['user_id'];
                $gids = $pmrequests->profile_magic_get_user_field_value($uid,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }

                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $post = get_post($postid);
                $post_author = $post->post_author;
                $display_name2 = $pmrequests->pm_get_display_name($post_author);
                $profile_url2 = $pmrequests->pm_get_user_profile_url($post_author);
                $posttype = $post->post_type;
                $post_link = get_permalink($postid);
                if($posttype=='pg_groupwalls' && $comment_approved===1)
                {
                    $type = 'group';
                    $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('replied to','profilegrid-user-activities').' '.'<a href="'.$post_link.'">'. __('a post','profilegrid-user-activities').'</a> '. __('by','profilegrid-user-activities').' '.'<a href="'.$profile_url2.'">'.$display_name2.'</a>';
                    $this->pg_add_user_activities($groupid,$uid,$type,$activities);
                }
            endif;
        }
        
        
        
        public function profilegrid_user_activities_group_photo_comment($comment_ID, $comment_approved,$comment)
        {
           
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_group_photo_comment_activities','0')==1):
                $pmrequests = new PM_request;
                $postid = $comment['comment_post_ID'];
                 $identifier = 'PHOTOS';
                $where = 1;
                $additional = "attachment_id = $postid";
                $photo = $dbhandler->get_all_result($identifier, $column = '*', $where, 'results', $offset=0, $limit=false, $sort_by = null, $descending=false,$additional);
                if( sizeof($photo)>0 && $comment_approved===1)
                {
                $uid = $comment['user_id'];
                $gids = $pmrequests->profile_magic_get_user_field_value($uid,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $post = get_post($postid);
                $post_author = $post->post_author;
                $display_name2 = $pmrequests->pm_get_display_name($post_author);
                $profile_url2 = $pmrequests->pm_get_user_profile_url($post_author);
                $posttype = $post->post_type;
                $post_link = get_permalink($postid);
               
                    $type = 'group';
                    $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('commented on ','profilegrid-user-activities').' '.'<a href="'.$post_link.'">'. __('a group photo','profilegrid-user-activities').'</a> '. __('by','profilegrid-user-activities').' '.'<a href="'.$profile_url2.'">'.$display_name2.'</a>';
                    $this->pg_add_user_activities($groupid,$uid,$type,$activities);
                }
            endif;
        }
        
        
        public function profilegrid_user_activities_update_group_icon($data,$old_data,$gid)
        {
            $pmrequests = new PM_request;
            $uid = get_current_user_id();
            $type = 'group';
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_group_icon_change_activities','0')==1):
                if(isset($data['group_icon']) && isset($old_data->group_icon) && $data['group_icon']!=$old_data->group_icon)
                {
                    $activities = __('Group icon was updated.','profilegrid-user-activities');
                    $this->pg_add_user_activities($gid,$uid,$type,$activities);
                }
            endif;
            if($dbhandler->get_global_option_value('pm_enable_group_name_change_activities','0')==1):
                if(isset($data['group_name']) && isset($old_data->group_name) && $data['group_name']!=$old_data->group_name)
                {
                    $group_url  = $pmrequests->profile_magic_get_frontend_url('pm_group_page','',$gid);
                    $group_url = add_query_arg( 'gid',$gid, $group_url );
                    $activities = $old_data->group_name.' '.__('name changed to.','profilegrid-user-activities').' '.'<a href="'.$group_url.'">'.$data['group_name'].'</a>';
                    $this->pg_add_user_activities($gid,$uid,$type,$activities);
                }
            endif;
            
        }
        
        public function profilegrid_user_activities_user_leave_group($uid,$gid)
        {
            $dbhandler = new PM_DBhandler;
            $cuid = get_current_user_id();
            if($dbhandler->get_global_option_value('pm_enable_user_left_activities','0')==1 && $cuid==$uid):
                $pmrequests = new PM_request;
                $type = 'group';
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('left the group','profilegrid-user-activities');
                $this->pg_add_user_activities($gid,$uid,$type,$activities);
            endif;
        }
        
        public function profilegrid_user_activities_group_create($gid)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_group_create_activities','0')==1):
                $pmrequests = new PM_request;
                $type = 'group';
                $time = date("jS M Y");
                $uid = get_current_user_id();
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $group_name = $dbhandler->get_value('GROUPS','group_name',$gid);
                $activities = $group_name.' '. __('Group started by','profilegrid-user-activities').' '.'<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('on','profilegrid-user-activities').' '.$time;
                $this->pg_add_user_activities($gid,$uid,$type,$activities);
            endif;
        }
        
        public function profilegrid_user_activities_remove_group_manager($gid,$uid)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_remove_group_manager_activities','0')==1):
                $pmrequests = new PM_request;
                $type = 'group';
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('is no longer manager of the group','profilegrid-user-activities');
                $this->pg_add_user_activities($gid,$uid,$type,$activities);
            endif;
        }
        
        public function profilegrid_user_activities_assign_group_manager($gid,$uid)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_new_group_manager_activities','0')==1):
                $pmrequests = new PM_request;
                $type = 'group';
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('is now manager of the group','profilegrid-user-activities');
                $this->pg_add_user_activities($gid,$uid,$type,$activities);
            endif;
            
        }
        
        public function profilegrid_user_activities_group_registration_full($gid,$uid)
        {
            $dbhandler = new PM_DBhandler;
            $pmrequests = new PM_request;
            $is_group_limit = $dbhandler->get_value('GROUPS','is_group_limit',$gid);
            $group_name = $dbhandler->get_value('GROUPS','group_name',$gid);
            $meta_query_array = $pmrequests->pm_get_user_meta_query(array('gid'=>$gid));
            $limit = $dbhandler->get_value('GROUPS','group_limit',$gid);
            $members_reach = $dbhandler->get_global_option_value('pm_activities_members_reach_multiply','');
            $total_users_in_group = count($dbhandler->pm_get_all_users('',$meta_query_array));
            if($is_group_limit==1 && $dbhandler->get_global_option_value('pm_enable_registration_full_activities','0')==1)
            {
                if($limit == $total_users_in_group)
                {
                    $type = 'group';
                    $activities = $group_name.' '. __('Group membership limit reached','profilegrid-user-activities');
                    $this->pg_add_user_activities($gid,$uid,$type,$activities);
            
                }
            }
            
            if($dbhandler->get_global_option_value('pm_enable_group_members_reach_activities','0')==1 && $members_reach!='' && $members_reach<=$total_users_in_group && ($total_users_in_group%$members_reach==0))
            {
                $type = 'group';
                   $messge = $group_name .' now has %d members' ; 
                $activities =  sprintf(__($messge,'profilegrid-user-activities'),$total_users_in_group);
                $this->pg_add_user_activities($gid,$uid,$type,$activities);
            }
            
        }
        
        
        public function profilegrid_user_activities_bbPress_topic_created($topic_id)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_create_bbpress_topic_activities','0')==1):   
                $pmrequests = new PM_request;
                $post = get_post($topic_id);
                $post_link = get_permalink($topic_id);
                $uid = $post->post_author; /* Post author ID. */
                $gids = $pmrequests->profile_magic_get_user_field_value($uid,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }
                $type = 'bbPress';
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('created a','profilegrid-user-activities').' '.'<a href="'.$post_link.'">'. __('topic','profilegrid-user-activities').'</a> ';
                $this->pg_add_user_activities($groupid,$uid,$type,$activities);
             endif;
        }
        
        
         public function profilegrid_user_activities_bbPress_topic_reply($reply_id)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_reply_bbpress_topic_activities','0')==1):   
                $pmrequests = new PM_request;
                $topic_id = bbp_get_reply_topic_id ($reply_id) ;
                $post = get_post($topic_id);
                $post_link = get_permalink($topic_id);
                $uid = $post->post_author; /* Post author ID. */
                $replier_id=bbp_get_reply_author_id($reply_id);
                $display_name_replier = $pmrequests->pm_get_display_name($replier_id);
                $profile_url_replier = $pmrequests->pm_get_user_profile_url($replier_id);
                $gids = $pmrequests->profile_magic_get_user_field_value($replier_id,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }
                $type = 'bbPress';
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                $activities = '<a href="'.$profile_url_replier.'">'.$display_name_replier.'</a>'.' '. __('replied on a','profilegrid-user-activities').' '.'<a href="'.$post_link.'">'. __('topic','profilegrid-user-activities').'</a> '. __('by','profilegrid-user-activities').' '.'<a href="'.$profile_url.'">'.$display_name.'</a>';
                $this->pg_add_user_activities($groupid,$uid,$type,$activities);
             endif;
        }
        
        
        public function profilegrid_user_activities_mycred_user_award_points( $user_id, $current_balance, $amount, $type)
        {
       $dbhandler = new PM_DBhandler;
       if($dbhandler->get_global_option_value('pm_enable_user_award_points_activities','0')==1):   
       if ( $amount > 0 ) 
        {
            $pmrequests = new PM_request;
            $display_name = $pmrequests->pm_get_display_name($user_id);
            $profile_url = $pmrequests->pm_get_user_profile_url($user_id);
            $gids = $pmrequests->profile_magic_get_user_field_value($user_id,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }
            $type = 'myCred';
        $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('awarded by ','profilegrid-user-activities').$amount . __(' points','profilegrid-user-activities');
         $this->pg_add_user_activities($groupid,$user_id,$type,$activities);
	}
        endif;
        }
        
        
         public function profilegrid_user_activities_update_profile_label($uid, $labels)
        {
            
             $dbhandler = new PM_DBhandler;
       if($dbhandler->get_global_option_value('pm_enable_assign_profile_label_activities','0')==1):   
         
           if(!empty($labels)):
               $label_array = array();
                foreach($labels as $label)
                     {
                        $labelobj = $dbhandler->get_row('PROLABELS',$label);
                         $label_array[] = $labelobj->label_title ;                   
                     }
            $label_html = implode(",",$label_array);
            $pmrequests = new PM_request;
            $labels_string = implode(',',$labels);
            $display_name = $pmrequests->pm_get_display_name($uid);
            $profile_url = $pmrequests->pm_get_user_profile_url($uid);
            $gids = $pmrequests->profile_magic_get_user_field_value($uid,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }
            $type = 'labels';
            
         $activities = __('Labels ','profilegrid-user-activities'). $label_html . __(' are assigned to ','profilegrid-user-activities') . '<a href="'.$profile_url.'">'.$display_name.'</a>';
         $this->pg_add_user_activities($groupid,$uid,$type,$activities);
       endif;
      endif;
        }
        
        public function profilegrid_user_activities_update_profile_status($uid,$attachment_id,$status_id)
        {
            $dbhandler = new PM_DBhandler;
            $pmrequests = new PM_request;
            $display_name = $pmrequests->pm_get_display_name($uid);
            $profile_url = $pmrequests->pm_get_user_profile_url($uid);
            $gids = $pmrequests->profile_magic_get_user_field_value($uid,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }
            $type = 'status';
            if($dbhandler->get_global_option_value('pm_enable_upload_image_status_activities','0')==1 && $attachment_id<>''):   
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'. __(' uploaded a image on status ','profilegrid-user-activities')  ;
                $this->pg_add_user_activities($groupid,$uid,$type,$activities);
            elseif($dbhandler->get_global_option_value('pm_enable_add_text_status_activities','0')==1 && $attachment_id==''):   
               $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'. __(' added a text status ','profilegrid-user-activities')  ;
                $this->pg_add_user_activities($groupid,$uid,$type,$activities);
            endif;
        }
        
         public function profilegrid_user_activities_user_photo_upload($album_id,$uid)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_upload_user_photo_activities','0')==1):
                $pmrequests = new PM_request;
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                 $gids = $pmrequests->profile_magic_get_user_field_value($uid,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }
                $type = 'photo';
                if ($album_id==0):
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('added a new photo','profilegrid-user-activities');
                else:
                  $identifier = 'USER_ALBUMS';
                  $where = 1;
                $additional = "id = $album_id";
                $album = $dbhandler->get_row($identifier,$album_id);
                $album_name = $album->name;
                 $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('added a new photo to album ','profilegrid-user-activities'). $album_name;
                endif;
                $this->pg_add_user_activities($groupid,$uid,$type,$activities);
            endif;
        }
        
        public function profilegrid_user_activities_create_user_album($album_id,$uid)
        {
            $dbhandler = new PM_DBhandler;
            if($dbhandler->get_global_option_value('pm_enable_create_user_album_activities','0')==1):
                $pmrequests = new PM_request;
                $identifier = 'USER_ALBUMS';
                $where = 1;
                $additional = "id = $album_id";
                $album = $dbhandler->get_row($identifier,$album_id);
                $album_name = $album->name;
                $display_name = $pmrequests->pm_get_display_name($uid);
                $profile_url = $pmrequests->pm_get_user_profile_url($uid);
                 $gids = $pmrequests->profile_magic_get_user_field_value($uid,'pm_group');  
                $gid = $pmrequests->pg_filter_users_group_ids($gids);
                if(isset($gid) && !empty($gid))
                {
                    if(isset($gid[0]))
                    {
                        $groupid = $gid[0];
                    }
                }
                $type = 'album';
                $activities = '<a href="'.$profile_url.'">'.$display_name.'</a>'.' '. __('created a album ','profilegrid-user-activities'). $album_name .__(' on profile','profilegrid-user-activities');
                $this->pg_add_user_activities($gid,$uid,$type,$activities);
            endif;
        }
        
        public function register_shortcodes()
        {
            add_shortcode( 'profilegrid_user_activities', array( $this, 'pm_user_activities_shortcode' ) );
        }
               
        public function pm_user_activities_shortcode($instance)
        {
            $dbhandler = new PM_DBhandler;
            ob_start();
            $html = ob_get_contents();
            $count = (isset($instance['count']) && $instance['count']!='') ? $instance['count'] : 10;
            $order = (isset($instance['order']) && $instance['order']!='') ? $instance['order'] : 'desc';
            $groups = (isset($instance['gid']) && $instance['gid']!='') ? $instance['gid'] : 'all';
            $activites_funciton = new Profilegrid_User_Activities_Functions;
            $activites_funciton->users_activities_html($count,$order,$groups);
            $html = ob_get_contents();
            ob_end_clean();
            return $html;
        }
        
}
