<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Profilegrid_Userid_Slug_Changer
 * @subpackage Profilegrid_Userid_Slug_Changer/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Profilegrid_Userid_Slug_Changer
 * @subpackage Profilegrid_Userid_Slug_Changer/public
 * @author     Your Name <email@example.com>
 */
class Profilegrid_Userid_Slug_Changer_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $profilegrid_userid_slug_changer    The ID of this plugin.
	 */
	private $profilegrid_userid_slug_changer;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $profilegrid_userid_slug_changer       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $profilegrid_userid_slug_changer, $version ) {

		$this->profilegrid_userid_slug_changer = $profilegrid_userid_slug_changer;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_Userid_Slug_Changer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_Userid_Slug_Changer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->profilegrid_userid_slug_changer, plugin_dir_url( __FILE__ ) . 'css/profilegrid-userid-slug-changer-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Profilegrid_Userid_Slug_Changer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Profilegrid_Userid_Slug_Changer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
                wp_enqueue_script( $this->profilegrid_userid_slug_changer, plugin_dir_url( __FILE__ ) . 'js/profilegrid-userid-slug-changer-public.js', array( 'jquery' ), $this->version, false );
             
	}
        
        public function pm_get_profile_slug_by_id($slug,$uid)
        {
            $dbhandler = new PM_DBhandler;
            $pmrequest = new PM_request;
            
            if($dbhandler->get_global_option_value('pm_enable_uid_changer','0')==1):
            $type = $dbhandler->get_global_option_value('pm_profile_url','uid');
            switch($type)
            {
                case 'random_number':
                        $slug = $pmrequest->pm_encrypt_decrypt_pass('encrypt',$uid);
                        break;
                case 'user_name':
                        $user_info = get_userdata($uid);
                        $slug =  $user_info->user_login;
                        break;
                case 'safe_random_number':
                        $slug = $pmrequest->pm_encrypt_decrypt_pass('encrypt',$uid);
                        break;
                case 'safe_user_name':
                        $user_info = get_userdata($uid);
                        $slug =  $user_info->user_login;
                        break;    
                    
                default:
                        $slug = $uid;
                        break;
            }
            endif;
            return $slug;
            
        }
        
        public function pm_get_uid_from_profile_slug($uid,$slug)
        {
            $dbhandler = new PM_DBhandler;
            $pmrequest = new PM_request;
            if($dbhandler->get_global_option_value('pm_enable_uid_changer','0')==1):
            $type = $dbhandler->get_global_option_value('pm_profile_url','uid');
            switch($type)
            {
                case 'random_number':
                        $uid = $pmrequest->pm_encrypt_decrypt_pass('decrypt',$slug);
                        break;
                case 'user_name':
                        $user_info = get_user_by('login',$slug);
                        if(!empty($user_info))
                        $uid =  $user_info->ID;
                        break;
                case 'safe_random_number':
                        $uid = $pmrequest->pm_encrypt_decrypt_pass('decrypt',$slug);
                        break;
                case 'safe_user_name':
                        $user_info = get_user_by('login',$slug);
                        if(!empty($user_info))
                        $uid =  $user_info->ID;
                        break;
                default:
                        $uid = $slug;
                        break;
            }
            endif;
            return $uid;
        }
        
        public function pm_get_profile_url($url,$uid)
        {
            $pmrequest = new PM_request;
            $dbhandler = new PM_DBhandler;
            $myprofile_url = $pmrequest->profile_magic_get_frontend_url( 'pm_user_profile_page', '' );
            $slug = $pmrequest->pm_get_profile_slug_by_id($uid);
            $type = $dbhandler->get_global_option_value('pm_profile_url','uid');
            $base = $dbhandler->get_global_option_value('pm_user_profile_base','uid');
            //echo $url;die;
            //return $slug;
            switch($type)
            {
            
                case 'safe_uid':
                case 'safe_random_number':
                case 'safe_user_name':
                    $url = $myprofile_url.$base.'/'.$slug;
                    break;
                default:
                        $url = $url;
                        break;
            }
            return $url;
        }
        
        public function pm_pass_slug_rules()
        {
            add_rewrite_tag('%uid%', '([^&]+)');
        }
        
        public function pm_apply_slug_rules()
        {
           //echo $_GET['uid'];
            if(class_exists('Profile_Magic')){
                $dbhandler = new PM_DBhandler;
                $pmrequest = new PM_request;
                $type = $dbhandler->get_global_option_value('pm_profile_url','uid');
                $base = $dbhandler->get_global_option_value('pm_user_profile_base','uid');
                $myprofile_url = basename($pmrequest->profile_magic_get_frontend_url( 'pm_user_profile_page', '' ));
              //  echo $myprofile_url;
                if($type=='safe_uid' || $type=='safe_user_name' || $type=='safe_random_number' )
                {
                    global $wp_rewrite;
                    add_rewrite_rule( "$myprofile_url/$base/(.+)?$","index.php/$myprofile_url/?uid=$1", "top");
                    
                }
            }

        }
        
        public function pm_filter_query_vars($query_vars)
        {
            $query_vars[] = 'uid';
            return $query_vars;
        }
        
        public function pm_rewrite_endpoint()
        {
            if(class_exists('Profile_Magic')){
                $dbhandler = new PM_DBhandler;
                $base = $dbhandler->get_global_option_value('pm_user_profile_base','uid');
                add_rewrite_endpoint( $base, EP_ALL );
            
            }
            
        }
        
}
